Crate pint_abi_gen

Crate pint_abi_gen 

Macros for generating items from pint-generated contract ABI JSON.

The entry points for this crate are:

For a given contract, the following items are generated:

  • A mod representing storage.
  • For each predicate, a module with the following:
    • An Args struct for the predicate’s arguments.

The aim for the generated items is to ease the construction of solutions including the encoding of keys, values and mutations from higher-level types.

Macros

from_file
Generate all items from an ABI JSON file at the given path.
from_str
Generate all items from a raw ABI JSON string.