Macros for generating items from pint-generated contract ABI JSON.
The entry points for this crate are:
For a given contract, the following items are generated:
- A
modrepresentingstorage. - For each
predicate, a module with the following:- An
Argsstruct for the predicate’s arguments.
- An
The aim for the generated items is to ease the construction of solutions including the encoding of keys, values and mutations from higher-level types.